@@ -292,9 +292,9 @@ def calcGroupCutoff(args):
     fcatFn.checkFileExist(coreDir + '/core_orthologs/' + coreSet, '')
     annoDir = args.annoDir
     if annoDir == '':
-        annoDir = '%s/fcatOutput/%s/weight_dir' % (args.outDir, args.coreSet)
-        Path(annoDir).mkdir(parents=True, exist_ok=True)
-        # annoDir = '%s/weight_dir' % coreDir
+        # annoDir = '%s/fcatOutput/%s/weight_dir' % (args.outDir, args.coreSet)
+        # Path(annoDir).mkdir(parents=True, exist_ok=True)
+        annoDir = '%s/weight_dir' % coreDir
     annoDir = os.path.abspath(annoDir)
     for annoFile in glob.glob('%s/weight_dir/*.json' % args.coreDir):
         annoFileName = annoFile.split('/')[-1]
@@ -348,7 +348,7 @@ def calcGroupCutoff(args):
     pool.join()
 
 def main():
-    version = '0.1.1'
+    version = '0.1.4'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
