@@ -194,12 +194,16 @@ def calcFAS(coreDir, outDir, coreSet, queryID, annoDir, cpus, force):
                     if os.path.isdir(refDir + '/' + groupID):
                         singleFa = '%s/%s/%s.extended.fa' % (refDir, groupID, groupID)
                         if os.path.exists(singleFa):
+                            with open(singleFa) as f:
+                                if not queryID in f.read():
+                                    missing.append(groupID)
                             shutil.copyfileobj(open(singleFa, 'rb'), mergedFaFile)
                         else:
                             missing.append(groupID)
                 mergedFaFile.close()
                 # calculate fas scores for merged extended.fa using fas.runFdogFas
                 fdogFAS = 'fas.runFdogFas -i %s -w %s --cores %s --redo_anno --featuretypes %s' % (mergedFa, annoDir, cpus, annoToolsFcat)
+                print(fdogFAS)
                 try:
                     subprocess.run([fdogFAS], shell=True, check=True)
                 except:
@@ -241,6 +245,7 @@ def calcFASall(coreDir, outDir, coreSet, queryID, annoDir, cpus, force):
         mergedFaFile.close()
         # calculate fas scores for merged _all.extended.fa using fas.runFdogFas
         fdogFAS = 'fas.runFdogFas -i %s -w %s --cores %s --redo_anno --featuretypes %s' % (mergedFa, annoDir, cpus, annoToolsFcat)
+        print(fdogFAS)
         try:
             subprocess.run([fdogFAS], shell=True, check=True)
         except:
@@ -380,7 +385,7 @@ def searchOrtho(args):
     blastDir = os.path.abspath(blastDir)
     fcatFn.checkFileExist(blastDir, 'Please set path to blastDB using --blastDir option.')
     annoDir = args.annoDir
-    if annoDir == '':
+    if annoDir == '' or annoDir == '%s/weight_dir' % os.path.abspath(args.coreDir) or annoDir == '%s/weight_dir/' % os.path.abspath(args.coreDir):
         annoDir = '%s/fcatOutput/%s/weight_dir' % (outDir, args.coreSet)
         Path(annoDir).mkdir(parents=True, exist_ok=True)
         # annoDir = '%s/weight_dir' % coreDir
@@ -474,7 +479,7 @@ def searchOrtho(args):
     print('Done! Check output in %s' % fcatOut)
 
 def main():
-    version = '0.1.1'
+    version = '0.1.4'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
